@@ -5,11 +5,11 @@ import os
 import signal
 import sqlite3
 import tempfile
-from copy import copy
 from collections import deque
 from contextlib import contextmanager
-from itertools import (chain, groupby, islice, product,
-                       dropwhile, takewhile, zip_longest)
+from copy import copy
+from itertools import (chain, dropwhile, groupby, islice, product, takewhile,
+                       zip_longest)
 from pathlib import Path, PurePath
 
 
@@ -68,10 +68,10 @@ class Rows:
             }]
 
     def __str__(self):
-        return "\n".join(str(r) for r in self.iter())
+        return "\n".join(str(r) for r in self._iter())
 
     def __getitem__(self, col):
-        return [r[col] for r in self.iter()]
+        return [r[col] for r in self._iter()]
 
     def zip(self, other):
         newself = copy(self)
@@ -208,7 +208,8 @@ class Rows:
 
         return newself
 
-    def apply(self, fn):
+    # End-users might not be able to pass proper functions.
+    def _apply(self, fn):
         newself = copy(self)
         pgen = newself._history[-1]['genfn']
 
@@ -255,6 +256,7 @@ class Rows:
 
         return newself
 
+    # TODO: not sure 'join' can completely replace this one.
     def _merge(self, fn, other):
         newself = copy(self)
         pgen = newself._history[-1]['genfn']
@@ -279,9 +281,9 @@ class Rows:
                     if isinstance(x, dict):
                         yield x
                     elif isinstance(x, Rows):
-                        yield from x.iter()
+                        yield from x._iter()
                 return gen
-            return self.apply(_fn2gen(fn))
+            return self._apply(_fn2gen(fn))
 
         elif self._history[-1]['cmd'] == 'windowed':
             def _fn2gen1(f):
@@ -290,10 +292,10 @@ class Rows:
                     if isinstance(x, dict):
                         yield x
                     elif isinstance(x, Rows):
-                        yield from x.iter()
+                        yield from x._iter()
                 return gen
 
-            return self.apply(_fn2gen1(fn))
+            return self._apply(_fn2gen1(fn))
 
         # single row
         def _fn2gen_single(f):
@@ -302,9 +304,9 @@ class Rows:
                 if isinstance(x, dict):
                     yield x
                 elif isinstance(x, Rows):
-                    yield from x.iter()
+                    yield from x._iter()
             return gen
-        return self.apply(_fn2gen_single(fn))
+        return self._apply(_fn2gen_single(fn))
 
     def by(self, *cols):
         # need to cut out 'desc', 'asc'
@@ -316,7 +318,7 @@ class Rows:
             if pred(r):
                 yield r
 
-        return self.apply(gen)
+        return self._apply(gen)
 
     def update(self, **kwargs):
         def updatefn1(r):
@@ -331,8 +333,8 @@ class Rows:
             yield r
 
         if self._history[0]['cmd'] == 'fetch':
-            return self.apply(updatefn2)
-        return self.apply(updatefn1)
+            return self._apply(updatefn2)
+        return self._apply(updatefn1)
 
     # pretty expensive for what it actually does
     # but this version does not depend on the order of rows.
@@ -343,7 +345,7 @@ class Rows:
             yield {kwargs_rev.get(oldkey, oldkey): v
                    for oldkey, v in r.items()}
 
-        return self.apply(renamefn)
+        return self._apply(renamefn)
 
     def fold(self, **kwargs):
         gcols = []
@@ -365,16 +367,16 @@ class Rows:
             yield r
 
         if self._history[-1]['cmd'] == 'windowed':
-            return self.apply(foldfn1)
+            return self._apply(foldfn1)
         if self._history[-1]['cmd'] == 'group':
-            return self.apply(foldfn2)
+            return self._apply(foldfn2)
         raise ValueError("fold must be preceded by grouping processes")
 
     def select(self, *cols):
         def selectfn(r):
             yield {col: r[col] for col in cols}
 
-        return self.apply(selectfn)
+        return self._apply(selectfn)
 
     def deselect(self, *cols):
         cols = set(cols)
@@ -382,7 +384,7 @@ class Rows:
         def deselectfn(r):
             yield {k: v for k, v in r.items() if k not in cols}
 
-        return self.apply(deselectfn)
+        return self._apply(deselectfn)
 
     def join(self, other, join_type="left"):
         if join_type.lower() == "inner":
@@ -507,7 +509,7 @@ class Rows:
         def distinctfn(_k, rs):
             yield next(rs)
 
-        return self.by(*columns).apply(distinctfn)
+        return self.by(*columns)._apply(distinctfn)
 
     def windowed(self, n, step):
         newself = copy(self)
@@ -569,21 +571,25 @@ class Rows:
         return newself
 
     def size(self):
+        # There are rooms for this to be more efficient because some of the
+        # methods do not affect the size of the Rows but 
+        # don't think it's worth the trouble.
         if len(self._history) == 1 and self._history[0]['cmd'] == 'fetch':
             origin = self._history[0]
             return _get_size(origin['conn'], origin['tname'])
         elif len(self._history) == 1 and self._history[0]['cmd'] == 'read':
             return len(self._src)
-        return sum(1 for _ in self.iter())
+        return sum(1 for _ in self._iter())
 
-    # iter is not safe to end-users, because it can open the database.
-    # This should be used in a controlled way.
-    def iter(self):
+    # iter is not safe to end-users, because the generator might not be
+    # terminated after the database connection is closed.
+    # This should be used in a controlled manner.
+    def _iter(self):
         yield from self._history[-1]['genfn']()
 
     # list is safe, because it completes the iteration.
     def list(self):
-        return list(self.iter())
+        return list(self._iter())
 
 
 def _insert_statement(name, d):
@@ -690,7 +696,7 @@ def _step(fn, krs1, krs2):
 
 
 def _rows2iter(obj):
-    return obj.iter() if isinstance(obj, Rows) else iter(obj)
+    return obj._iter() if isinstance(obj, Rows) else iter(obj)
 
 
 def _build_initgen(conn, tname, cols):
@@ -707,7 +713,7 @@ def _build_initgen(conn, tname, cols):
 
 def _get_size(conn, tname):
     try:
-        res = conn._dbconn.cursor().execute(f"select count(1) from {tname}") 
+        res = conn._dbconn.cursor().execute(f"select count(1) from {tname}")
         return res.fetchone()['count(1)']
     except (AttributeError, sqlite3.ProgrammingError):
         with _connect(conn._dbfile) as c:
