@@ -38,22 +38,21 @@ class TestCore(unittest.TestCase):
 
     def test_size(self):
         conn = Conn(self.dbfile)
-        conn['t1'] = self.t1 
+        conn['t1'] = self.t1
 
         self.assertEqual(conn['t1'].size(), len(self.t1))
         # size is executed while the connection is open
-        self.assertEqual(conn['t1'].update(n=lambda r: conn['t1'].size())["n"], 
-            [7] * 7)
+        self.assertEqual(conn['t1'].update(n=lambda r: conn['t1'].size())["n"],
+                         [7] * 7)
         # size is executed when the connection is closed
-        self.assertEqual(conn['t1'].update(n=conn['t1'].size())["n"], 
-            [7] * 7)
+        self.assertEqual(conn['t1'].update(n=conn['t1'].size())["n"],
+                         [7] * 7)
 
         rs = Rows(self.t1)
         self.assertEqual(rs.size(), len(self.t1))
 
-        rs1 = rs.islice(3,6)
+        rs1 = rs.islice(3, 6)
         self.assertEqual(rs1.size(), 3)
-         
 
     def test_wierd(self):
         conn = Conn(self.dbfile)
@@ -76,7 +75,7 @@ class TestCore(unittest.TestCase):
         # the following code does not work, you cannot execute a fetch
         # while another fetch is being done.
         # So iter should not be exposed.
-        # for r1, r2 in zip(rs1.iter(), rs2.iter()):
+        # for r1, r2 in zip(rs1._iter(), rs2._iter()):
         #     print(r1, r2)
 
         rs1 = rs1.list()
@@ -334,7 +333,7 @@ class TestCore(unittest.TestCase):
         conn['t1_sum'] = conn['t1'].by('col1')\
             .map(sum_by_col1)
 
-        self.assertEqual(list(conn['t1_sum'].iter()),
+        self.assertEqual(list(conn['t1_sum']._iter()),
                          [{'col1': 'a', 'col2': 9},
                           {'col1': 'b', 'col2': 1},
                           {'col1': 'c', 'col2': 14},
@@ -360,7 +359,7 @@ class TestCore(unittest.TestCase):
         import pandas as pd
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
-        df = pd.DataFrame(conn['t1'].iter())
+        df = pd.DataFrame(conn['t1']._iter())
         conn['t1_copy'] = df.to_dict('records')
         self.assertEqual(conn['t1'].list(), conn['t1_copy'].list())
 
@@ -382,7 +381,7 @@ class TestCore(unittest.TestCase):
         conn1 = Conn(self.dbfile1)
         conn1['t1_sum'] = conn['t1'].by('col1').map(sumit).by('tot').map(count)
         conn1['t1_sum2'] = conn['t1'].by('col1').map(sumit)\
-            .by('tot').map(count).iter()
+            .by('tot').map(count)._iter()
 
         self.assertEqual(conn['t1_sum'].list(), conn1['t1_sum'].list())
         self.assertEqual(conn['t1_sum'].list(), conn1['t1_sum2'].list())
@@ -415,8 +414,8 @@ class TestCore(unittest.TestCase):
         self.assertEqual(len(conn['t1'].islice(3, None).list()), 4)
         self.assertEqual(len(conn['t1'].islice(0, None, 3).list()), 3)
 
-        xs = conn['t1'].iter()
-        ys = conn['t2'].iter()
+        xs = conn['t1']._iter()
+        ys = conn['t2']._iter()
 
         conn['t1_2'] = ({**x, **y} for x, y in product(xs, ys))
 
@@ -496,11 +495,11 @@ class TestCore(unittest.TestCase):
             col3=lambda r: r['col1'] + str(r['col2'])
         )
 
-        r = next(conn['t1_1'].select('col1', 'col3').iter())
+        r = next(conn['t1_1'].select('col1', 'col3')._iter())
         self.assertEqual(len(r), 2)
 
         # test deselect
-        r = next(conn['t1_1'].deselect('col1', 'col3').iter())
+        r = next(conn['t1_1'].deselect('col1', 'col3')._iter())
         self.assertEqual(len(r), 1)
 
     def test_join(self):
@@ -615,7 +614,7 @@ class TestCore(unittest.TestCase):
         conn['t1'] = self.t1
 
         [g1, g2, g3, g4] = [list(xs) for _, xs in conn['t1'].order(
-            'col1', 'col2 desc').group('col1').iter()]
+            'col1', 'col2 desc').group('col1')._iter()]
         self.assertEqual(
             g1, [{'col1': 'a', 'col2': 5}, {'col1': 'a', 'col2': 4}]
         )
@@ -634,12 +633,12 @@ class TestCore(unittest.TestCase):
         conn = Conn(self.dbfile)
         conn['t1'] = t1
 
-        for r1, r2 in zip(conn['t1'].list(), conn['t1'].iter()):
+        for r1, r2 in zip(conn['t1'].list(), conn['t1']._iter()):
             self.assertEqual(r1, r2)
 
         import pandas as pd
 
-        df = pd.DataFrame(conn['t1'].iter())
+        df = pd.DataFrame(conn['t1']._iter())
         conn['t1_copy'] = df.to_dict('records')
 
         self.assertEqual(conn['t1'].list(), conn['t1_copy'].list())
